validator

package
v1.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 3, 2018 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ValidateID

func ValidateID(fl validator.FieldLevel) bool

ValidateID is used to help to validate ID in a struct

func ValidateKey

func ValidateKey(fl validator.FieldLevel) bool

ValidateKey is used to help to validate key in a struct

func ValidatePassword

func ValidatePassword(fl validator.FieldLevel) bool

ValidatePassword is used to help to validate password in a struct

func ValidateUsername

func ValidateUsername(fl v.FieldLevel) bool

ValidateUsername is used to help to validate username in a struct

Types

This section is empty.

Jump to